# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTImportCloudObjectParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'public': 'bool',
        'owner_id': 'str',
        'mime_type': 'str',
        'owner_type': 'str',
        'cloud_object_id': 'str',
        'size_bytes': 'int',
        'access_token': 'str',
        'cloud_storage_provider': 'int',
        'cloud_storage_account_id': 'str',
        'url': 'str',
        'notify_user': 'bool',
        'unit': 'str',
        'split_assemblies_into_multiple_documents': 'bool',
        'flatten_assemblies': 'bool',
        'gety_axis_is_up': 'bool',
        'allow_faulty_parts': 'bool',
        'project_id': 'str',
        'parent_id': 'str',
        'foreign_id': 'str',
        'upload_id': 'str',
        'original_foreign_id': 'str',
        'import_within_document': 'bool',
        'blob_element_id': 'str',
        'blob_microversion_id': 'str',
        'specify_units': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'public': 'public',
        'owner_id': 'ownerId',
        'mime_type': 'mimeType',
        'owner_type': 'ownerType',
        'cloud_object_id': 'cloudObjectId',
        'size_bytes': 'sizeBytes',
        'access_token': 'accessToken',
        'cloud_storage_provider': 'cloudStorageProvider',
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'url': 'url',
        'notify_user': 'notifyUser',
        'unit': 'unit',
        'split_assemblies_into_multiple_documents': 'splitAssembliesIntoMultipleDocuments',
        'flatten_assemblies': 'flattenAssemblies',
        'gety_axis_is_up': 'getyAxisIsUp',
        'allow_faulty_parts': 'allowFaultyParts',
        'project_id': 'projectId',
        'parent_id': 'parentId',
        'foreign_id': 'foreignId',
        'upload_id': 'uploadId',
        'original_foreign_id': 'originalForeignId',
        'import_within_document': 'importWithinDocument',
        'blob_element_id': 'blobElementId',
        'blob_microversion_id': 'blobMicroversionId',
        'specify_units': 'specifyUnits'
    }

    def __init__(self, name=None, public=None, owner_id=None, mime_type=None, owner_type=None, cloud_object_id=None, size_bytes=None, access_token=None, cloud_storage_provider=None, cloud_storage_account_id=None, url=None, notify_user=None, unit=None, split_assemblies_into_multiple_documents=None, flatten_assemblies=None, gety_axis_is_up=None, allow_faulty_parts=None, project_id=None, parent_id=None, foreign_id=None, upload_id=None, original_foreign_id=None, import_within_document=None, blob_element_id=None, blob_microversion_id=None, specify_units=None):  # noqa: E501
        """BTImportCloudObjectParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._public = None
        self._owner_id = None
        self._mime_type = None
        self._owner_type = None
        self._cloud_object_id = None
        self._size_bytes = None
        self._access_token = None
        self._cloud_storage_provider = None
        self._cloud_storage_account_id = None
        self._url = None
        self._notify_user = None
        self._unit = None
        self._split_assemblies_into_multiple_documents = None
        self._flatten_assemblies = None
        self._gety_axis_is_up = None
        self._allow_faulty_parts = None
        self._project_id = None
        self._parent_id = None
        self._foreign_id = None
        self._upload_id = None
        self._original_foreign_id = None
        self._import_within_document = None
        self._blob_element_id = None
        self._blob_microversion_id = None
        self._specify_units = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if public is not None:
            self.public = public
        if owner_id is not None:
            self.owner_id = owner_id
        if mime_type is not None:
            self.mime_type = mime_type
        if owner_type is not None:
            self.owner_type = owner_type
        if cloud_object_id is not None:
            self.cloud_object_id = cloud_object_id
        if size_bytes is not None:
            self.size_bytes = size_bytes
        if access_token is not None:
            self.access_token = access_token
        if cloud_storage_provider is not None:
            self.cloud_storage_provider = cloud_storage_provider
        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if url is not None:
            self.url = url
        if notify_user is not None:
            self.notify_user = notify_user
        if unit is not None:
            self.unit = unit
        if split_assemblies_into_multiple_documents is not None:
            self.split_assemblies_into_multiple_documents = split_assemblies_into_multiple_documents
        if flatten_assemblies is not None:
            self.flatten_assemblies = flatten_assemblies
        if gety_axis_is_up is not None:
            self.gety_axis_is_up = gety_axis_is_up
        if allow_faulty_parts is not None:
            self.allow_faulty_parts = allow_faulty_parts
        if project_id is not None:
            self.project_id = project_id
        if parent_id is not None:
            self.parent_id = parent_id
        if foreign_id is not None:
            self.foreign_id = foreign_id
        if upload_id is not None:
            self.upload_id = upload_id
        if original_foreign_id is not None:
            self.original_foreign_id = original_foreign_id
        if import_within_document is not None:
            self.import_within_document = import_within_document
        if blob_element_id is not None:
            self.blob_element_id = blob_element_id
        if blob_microversion_id is not None:
            self.blob_microversion_id = blob_microversion_id
        if specify_units is not None:
            self.specify_units = specify_units

    @property
    def name(self):
        """Gets the name of this BTImportCloudObjectParams.  # noqa: E501


        :return: The name of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTImportCloudObjectParams.


        :param name: The name of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def public(self):
        """Gets the public of this BTImportCloudObjectParams.  # noqa: E501


        :return: The public of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this BTImportCloudObjectParams.


        :param public: The public of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def owner_id(self):
        """Gets the owner_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The owner_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTImportCloudObjectParams.


        :param owner_id: The owner_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def mime_type(self):
        """Gets the mime_type of this BTImportCloudObjectParams.  # noqa: E501


        :return: The mime_type of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this BTImportCloudObjectParams.


        :param mime_type: The mime_type of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def owner_type(self):
        """Gets the owner_type of this BTImportCloudObjectParams.  # noqa: E501


        :return: The owner_type of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTImportCloudObjectParams.


        :param owner_type: The owner_type of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["USER", "COMPANY", "ONSHAPE"]  # noqa: E501
        if owner_type not in allowed_values:
            raise ValueError(
                "Invalid value for `owner_type` ({0}), must be one of {1}"  # noqa: E501
                .format(owner_type, allowed_values)
            )

        self._owner_type = owner_type

    @property
    def cloud_object_id(self):
        """Gets the cloud_object_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The cloud_object_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_object_id

    @cloud_object_id.setter
    def cloud_object_id(self, cloud_object_id):
        """Sets the cloud_object_id of this BTImportCloudObjectParams.


        :param cloud_object_id: The cloud_object_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._cloud_object_id = cloud_object_id

    @property
    def size_bytes(self):
        """Gets the size_bytes of this BTImportCloudObjectParams.  # noqa: E501


        :return: The size_bytes of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: int
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes):
        """Sets the size_bytes of this BTImportCloudObjectParams.


        :param size_bytes: The size_bytes of this BTImportCloudObjectParams.  # noqa: E501
        :type: int
        """

        self._size_bytes = size_bytes

    @property
    def access_token(self):
        """Gets the access_token of this BTImportCloudObjectParams.  # noqa: E501


        :return: The access_token of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this BTImportCloudObjectParams.


        :param access_token: The access_token of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def cloud_storage_provider(self):
        """Gets the cloud_storage_provider of this BTImportCloudObjectParams.  # noqa: E501


        :return: The cloud_storage_provider of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: int
        """
        return self._cloud_storage_provider

    @cloud_storage_provider.setter
    def cloud_storage_provider(self, cloud_storage_provider):
        """Sets the cloud_storage_provider of this BTImportCloudObjectParams.


        :param cloud_storage_provider: The cloud_storage_provider of this BTImportCloudObjectParams.  # noqa: E501
        :type: int
        """

        self._cloud_storage_provider = cloud_storage_provider

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The cloud_storage_account_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this BTImportCloudObjectParams.


        :param cloud_storage_account_id: The cloud_storage_account_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def url(self):
        """Gets the url of this BTImportCloudObjectParams.  # noqa: E501


        :return: The url of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this BTImportCloudObjectParams.


        :param url: The url of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def notify_user(self):
        """Gets the notify_user of this BTImportCloudObjectParams.  # noqa: E501


        :return: The notify_user of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._notify_user

    @notify_user.setter
    def notify_user(self, notify_user):
        """Sets the notify_user of this BTImportCloudObjectParams.


        :param notify_user: The notify_user of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._notify_user = notify_user

    @property
    def unit(self):
        """Gets the unit of this BTImportCloudObjectParams.  # noqa: E501


        :return: The unit of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this BTImportCloudObjectParams.


        :param unit: The unit of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def split_assemblies_into_multiple_documents(self):
        """Gets the split_assemblies_into_multiple_documents of this BTImportCloudObjectParams.  # noqa: E501


        :return: The split_assemblies_into_multiple_documents of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._split_assemblies_into_multiple_documents

    @split_assemblies_into_multiple_documents.setter
    def split_assemblies_into_multiple_documents(self, split_assemblies_into_multiple_documents):
        """Sets the split_assemblies_into_multiple_documents of this BTImportCloudObjectParams.


        :param split_assemblies_into_multiple_documents: The split_assemblies_into_multiple_documents of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._split_assemblies_into_multiple_documents = split_assemblies_into_multiple_documents

    @property
    def flatten_assemblies(self):
        """Gets the flatten_assemblies of this BTImportCloudObjectParams.  # noqa: E501


        :return: The flatten_assemblies of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._flatten_assemblies

    @flatten_assemblies.setter
    def flatten_assemblies(self, flatten_assemblies):
        """Sets the flatten_assemblies of this BTImportCloudObjectParams.


        :param flatten_assemblies: The flatten_assemblies of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._flatten_assemblies = flatten_assemblies

    @property
    def gety_axis_is_up(self):
        """Gets the gety_axis_is_up of this BTImportCloudObjectParams.  # noqa: E501


        :return: The gety_axis_is_up of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._gety_axis_is_up

    @gety_axis_is_up.setter
    def gety_axis_is_up(self, gety_axis_is_up):
        """Sets the gety_axis_is_up of this BTImportCloudObjectParams.


        :param gety_axis_is_up: The gety_axis_is_up of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._gety_axis_is_up = gety_axis_is_up

    @property
    def allow_faulty_parts(self):
        """Gets the allow_faulty_parts of this BTImportCloudObjectParams.  # noqa: E501


        :return: The allow_faulty_parts of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._allow_faulty_parts

    @allow_faulty_parts.setter
    def allow_faulty_parts(self, allow_faulty_parts):
        """Sets the allow_faulty_parts of this BTImportCloudObjectParams.


        :param allow_faulty_parts: The allow_faulty_parts of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._allow_faulty_parts = allow_faulty_parts

    @property
    def project_id(self):
        """Gets the project_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The project_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTImportCloudObjectParams.


        :param project_id: The project_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def parent_id(self):
        """Gets the parent_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The parent_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTImportCloudObjectParams.


        :param parent_id: The parent_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def foreign_id(self):
        """Gets the foreign_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The foreign_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._foreign_id

    @foreign_id.setter
    def foreign_id(self, foreign_id):
        """Sets the foreign_id of this BTImportCloudObjectParams.


        :param foreign_id: The foreign_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._foreign_id = foreign_id

    @property
    def upload_id(self):
        """Gets the upload_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The upload_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this BTImportCloudObjectParams.


        :param upload_id: The upload_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._upload_id = upload_id

    @property
    def original_foreign_id(self):
        """Gets the original_foreign_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The original_foreign_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._original_foreign_id

    @original_foreign_id.setter
    def original_foreign_id(self, original_foreign_id):
        """Sets the original_foreign_id of this BTImportCloudObjectParams.


        :param original_foreign_id: The original_foreign_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._original_foreign_id = original_foreign_id

    @property
    def import_within_document(self):
        """Gets the import_within_document of this BTImportCloudObjectParams.  # noqa: E501


        :return: The import_within_document of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._import_within_document

    @import_within_document.setter
    def import_within_document(self, import_within_document):
        """Sets the import_within_document of this BTImportCloudObjectParams.


        :param import_within_document: The import_within_document of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._import_within_document = import_within_document

    @property
    def blob_element_id(self):
        """Gets the blob_element_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The blob_element_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_element_id

    @blob_element_id.setter
    def blob_element_id(self, blob_element_id):
        """Sets the blob_element_id of this BTImportCloudObjectParams.


        :param blob_element_id: The blob_element_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._blob_element_id = blob_element_id

    @property
    def blob_microversion_id(self):
        """Gets the blob_microversion_id of this BTImportCloudObjectParams.  # noqa: E501


        :return: The blob_microversion_id of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: str
        """
        return self._blob_microversion_id

    @blob_microversion_id.setter
    def blob_microversion_id(self, blob_microversion_id):
        """Sets the blob_microversion_id of this BTImportCloudObjectParams.


        :param blob_microversion_id: The blob_microversion_id of this BTImportCloudObjectParams.  # noqa: E501
        :type: str
        """

        self._blob_microversion_id = blob_microversion_id

    @property
    def specify_units(self):
        """Gets the specify_units of this BTImportCloudObjectParams.  # noqa: E501


        :return: The specify_units of this BTImportCloudObjectParams.  # noqa: E501
        :rtype: bool
        """
        return self._specify_units

    @specify_units.setter
    def specify_units(self, specify_units):
        """Sets the specify_units of this BTImportCloudObjectParams.


        :param specify_units: The specify_units of this BTImportCloudObjectParams.  # noqa: E501
        :type: bool
        """

        self._specify_units = specify_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTImportCloudObjectParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RequestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_key': 'str',
        'stripe_version': 'str',
        'idempotency_key': 'str',
        'stripe_account': 'str',
        'connect_timeout': 'int',
        'read_timeout': 'int'
    }

    attribute_map = {
        'api_key': 'apiKey',
        'stripe_version': 'stripeVersion',
        'idempotency_key': 'idempotencyKey',
        'stripe_account': 'stripeAccount',
        'connect_timeout': 'connectTimeout',
        'read_timeout': 'readTimeout'
    }

    def __init__(self, api_key=None, stripe_version=None, idempotency_key=None, stripe_account=None, connect_timeout=None, read_timeout=None):  # noqa: E501
        """RequestOptions - a model defined in OpenAPI"""  # noqa: E501

        self._api_key = None
        self._stripe_version = None
        self._idempotency_key = None
        self._stripe_account = None
        self._connect_timeout = None
        self._read_timeout = None
        self.discriminator = None

        if api_key is not None:
            self.api_key = api_key
        if stripe_version is not None:
            self.stripe_version = stripe_version
        if idempotency_key is not None:
            self.idempotency_key = idempotency_key
        if stripe_account is not None:
            self.stripe_account = stripe_account
        if connect_timeout is not None:
            self.connect_timeout = connect_timeout
        if read_timeout is not None:
            self.read_timeout = read_timeout

    @property
    def api_key(self):
        """Gets the api_key of this RequestOptions.  # noqa: E501


        :return: The api_key of this RequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this RequestOptions.


        :param api_key: The api_key of this RequestOptions.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def stripe_version(self):
        """Gets the stripe_version of this RequestOptions.  # noqa: E501


        :return: The stripe_version of this RequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._stripe_version

    @stripe_version.setter
    def stripe_version(self, stripe_version):
        """Sets the stripe_version of this RequestOptions.


        :param stripe_version: The stripe_version of this RequestOptions.  # noqa: E501
        :type: str
        """

        self._stripe_version = stripe_version

    @property
    def idempotency_key(self):
        """Gets the idempotency_key of this RequestOptions.  # noqa: E501


        :return: The idempotency_key of this RequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._idempotency_key

    @idempotency_key.setter
    def idempotency_key(self, idempotency_key):
        """Sets the idempotency_key of this RequestOptions.


        :param idempotency_key: The idempotency_key of this RequestOptions.  # noqa: E501
        :type: str
        """

        self._idempotency_key = idempotency_key

    @property
    def stripe_account(self):
        """Gets the stripe_account of this RequestOptions.  # noqa: E501


        :return: The stripe_account of this RequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._stripe_account

    @stripe_account.setter
    def stripe_account(self, stripe_account):
        """Sets the stripe_account of this RequestOptions.


        :param stripe_account: The stripe_account of this RequestOptions.  # noqa: E501
        :type: str
        """

        self._stripe_account = stripe_account

    @property
    def connect_timeout(self):
        """Gets the connect_timeout of this RequestOptions.  # noqa: E501


        :return: The connect_timeout of this RequestOptions.  # noqa: E501
        :rtype: int
        """
        return self._connect_timeout

    @connect_timeout.setter
    def connect_timeout(self, connect_timeout):
        """Sets the connect_timeout of this RequestOptions.


        :param connect_timeout: The connect_timeout of this RequestOptions.  # noqa: E501
        :type: int
        """

        self._connect_timeout = connect_timeout

    @property
    def read_timeout(self):
        """Gets the read_timeout of this RequestOptions.  # noqa: E501


        :return: The read_timeout of this RequestOptions.  # noqa: E501
        :rtype: int
        """
        return self._read_timeout

    @read_timeout.setter
    def read_timeout(self, read_timeout):
        """Sets the read_timeout of this RequestOptions.


        :param read_timeout: The read_timeout of this RequestOptions.  # noqa: E501
        :type: int
        """

        self._read_timeout = read_timeout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class BlobElementsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def upload_file_create_element(self, did, wid, **kwargs):  # noqa: E501
        """upload_file_create_element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_create_element(did, wid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param ContentDisposition content_disposition:
        :param object entity:
        :param BodyPartHeaders headers:
        :param BodyPartMediaType media_type:
        :param MessageBodyWorkers message_body_workers:
        :param MultiPart parent:
        :param object providers:
        :param list[BodyPart] body_parts:
        :param BodyPartHeaders parameterized_headers:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_file_create_element_with_http_info(did, wid, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_file_create_element_with_http_info(did, wid, **kwargs)  # noqa: E501
            return data

    def upload_file_create_element_with_http_info(self, did, wid, **kwargs):  # noqa: E501
        """upload_file_create_element  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_create_element_with_http_info(did, wid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param ContentDisposition content_disposition:
        :param object entity:
        :param BodyPartHeaders headers:
        :param BodyPartMediaType media_type:
        :param MessageBodyWorkers message_body_workers:
        :param MultiPart parent:
        :param object providers:
        :param list[BodyPart] body_parts:
        :param BodyPartHeaders parameterized_headers:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'content_disposition', 'entity', 'headers', 'media_type', 'message_body_workers', 'parent', 'providers', 'body_parts', 'parameterized_headers']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file_create_element" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `upload_file_create_element`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `upload_file_create_element`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'content_disposition' in local_var_params:
            form_params.append(('contentDisposition', local_var_params['content_disposition']))  # noqa: E501
        if 'entity' in local_var_params:
            form_params.append(('entity', local_var_params['entity']))  # noqa: E501
        if 'headers' in local_var_params:
            form_params.append(('headers', local_var_params['headers']))  # noqa: E501
        if 'media_type' in local_var_params:
            form_params.append(('mediaType', local_var_params['media_type']))  # noqa: E501
        if 'message_body_workers' in local_var_params:
            form_params.append(('messageBodyWorkers', local_var_params['message_body_workers']))  # noqa: E501
        if 'parent' in local_var_params:
            form_params.append(('parent', local_var_params['parent']))  # noqa: E501
        if 'providers' in local_var_params:
            form_params.append(('providers', local_var_params['providers']))  # noqa: E501
        if 'body_parts' in local_var_params:
            form_params.append(('bodyParts', local_var_params['body_parts']))  # noqa: E501
            collection_formats['bodyParts'] = 'csv'  # noqa: E501
        if 'parameterized_headers' in local_var_params:
            form_params.append(('parameterizedHeaders', local_var_params['parameterized_headers']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/blobelements/d/{did}/w/{wid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class ElementsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def copy_element_from_source_document1(self, did, wid, bt_copy_element_params, **kwargs):  # noqa: E501
        """copy_element_from_source_document1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.copy_element_from_source_document1(did, wid, bt_copy_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTCopyElementParams bt_copy_element_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.copy_element_from_source_document1_with_http_info(did, wid, bt_copy_element_params, **kwargs)  # noqa: E501
        else:
            (data) = self.copy_element_from_source_document1_with_http_info(did, wid, bt_copy_element_params, **kwargs)  # noqa: E501
            return data

    def copy_element_from_source_document1_with_http_info(self, did, wid, bt_copy_element_params, **kwargs):  # noqa: E501
        """copy_element_from_source_document1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.copy_element_from_source_document1_with_http_info(did, wid, bt_copy_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param BTCopyElementParams bt_copy_element_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'bt_copy_element_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method copy_element_from_source_document1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `copy_element_from_source_document1`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `copy_element_from_source_document1`")  # noqa: E501
        # verify the required parameter 'bt_copy_element_params' is set
        if ('bt_copy_element_params' not in local_var_params or
                local_var_params['bt_copy_element_params'] is None):
            raise ValueError("Missing the required parameter `bt_copy_element_params` when calling `copy_element_from_source_document1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_copy_element_params' in local_var_params:
            body_params = local_var_params['bt_copy_element_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/copyelement/{did}/workspace/{wid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def decode_configuration(self, did, wvm, wvmid, eid, cid, **kwargs):  # noqa: E501
        """decode_configuration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.decode_configuration(did, wvm, wvmid, eid, cid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str cid: (required)
        :param str link_document_id:
        :param bool include_display:
        :param bool configuration_is_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.decode_configuration_with_http_info(did, wvm, wvmid, eid, cid, **kwargs)  # noqa: E501
        else:
            (data) = self.decode_configuration_with_http_info(did, wvm, wvmid, eid, cid, **kwargs)  # noqa: E501
            return data

    def decode_configuration_with_http_info(self, did, wvm, wvmid, eid, cid, **kwargs):  # noqa: E501
        """decode_configuration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.decode_configuration_with_http_info(did, wvm, wvmid, eid, cid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str cid: (required)
        :param str link_document_id:
        :param bool include_display:
        :param bool configuration_is_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'cid', 'link_document_id', 'include_display', 'configuration_is_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method decode_configuration" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `decode_configuration`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `decode_configuration`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `decode_configuration`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `decode_configuration`")  # noqa: E501
        # verify the required parameter 'cid' is set
        if ('cid' not in local_var_params or
                local_var_params['cid'] is None):
            raise ValueError("Missing the required parameter `cid` when calling `decode_configuration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'cid' in local_var_params:
            path_params['cid'] = local_var_params['cid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'include_display' in local_var_params:
            query_params.append(('includeDisplay', local_var_params['include_display']))  # noqa: E501
        if 'configuration_is_id' in local_var_params:
            query_params.append(('configurationIsId', local_var_params['configuration_is_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/{wvm}/{wvmid}/e/{eid}/configurationencodings/{cid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete8(self, did, wid, eid, **kwargs):  # noqa: E501
        """delete8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete8(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete8_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete8_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
            return data

    def delete8_with_http_info(self, did, wid, eid, **kwargs):  # noqa: E501
        """delete8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete8_with_http_info(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete8" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `delete8`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `delete8`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `delete8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/w/{wid}/e/{eid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def encode_configuration_map(self, did, eid, bt_configuration_params, **kwargs):  # noqa: E501
        """encode_configuration_map  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.encode_configuration_map(did, eid, bt_configuration_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param BTConfigurationParams bt_configuration_params: (required)
        :param str version_id:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.encode_configuration_map_with_http_info(did, eid, bt_configuration_params, **kwargs)  # noqa: E501
        else:
            (data) = self.encode_configuration_map_with_http_info(did, eid, bt_configuration_params, **kwargs)  # noqa: E501
            return data

    def encode_configuration_map_with_http_info(self, did, eid, bt_configuration_params, **kwargs):  # noqa: E501
        """encode_configuration_map  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.encode_configuration_map_with_http_info(did, eid, bt_configuration_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str eid: (required)
        :param BTConfigurationParams bt_configuration_params: (required)
        :param str version_id:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'eid', 'bt_configuration_params', 'version_id', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method encode_configuration_map" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `encode_configuration_map`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `encode_configuration_map`")  # noqa: E501
        # verify the required parameter 'bt_configuration_params' is set
        if ('bt_configuration_params' not in local_var_params or
                local_var_params['bt_configuration_params'] is None):
            raise ValueError("Missing the required parameter `bt_configuration_params` when calling `encode_configuration_map`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'version_id' in local_var_params:
            query_params.append(('versionId', local_var_params['version_id']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_configuration_params' in local_var_params:
            body_params = local_var_params['bt_configuration_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/e/{eid}/configurationencodings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_configuration3(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_configuration3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_configuration3(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_configuration3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_configuration3_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_configuration3_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_configuration3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_configuration3_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_configuration3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_configuration3`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_configuration3`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_configuration3`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_configuration3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/{wvm}/{wvmid}/e/{eid}/configuration', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_element_by_version_deprecated(self, did, vid, **kwargs):  # noqa: E501
        """get_element_by_version_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_by_version_deprecated(did, vid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param bool with_thumbnails:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_element_by_version_deprecated_with_http_info(did, vid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_element_by_version_deprecated_with_http_info(did, vid, **kwargs)  # noqa: E501
            return data

    def get_element_by_version_deprecated_with_http_info(self, did, vid, **kwargs):  # noqa: E501
        """get_element_by_version_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_by_version_deprecated_with_http_info(did, vid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param bool with_thumbnails:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'vid', 'with_thumbnails']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_element_by_version_deprecated" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_element_by_version_deprecated`")  # noqa: E501
        # verify the required parameter 'vid' is set
        if ('vid' not in local_var_params or
                local_var_params['vid'] is None):
            raise ValueError("Missing the required parameter `vid` when calling `get_element_by_version_deprecated`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'vid' in local_var_params:
            path_params['vid'] = local_var_params['vid']  # noqa: E501

        query_params = []
        if 'with_thumbnails' in local_var_params:
            query_params.append(('withThumbnails', local_var_params['with_thumbnails']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/{did}/version/{vid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_element_by_workspace_deprecated(self, did, wid, **kwargs):  # noqa: E501
        """get_element_by_workspace_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_by_workspace_deprecated(did, wid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param bool with_thumbnails:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_element_by_workspace_deprecated_with_http_info(did, wid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_element_by_workspace_deprecated_with_http_info(did, wid, **kwargs)  # noqa: E501
            return data

    def get_element_by_workspace_deprecated_with_http_info(self, did, wid, **kwargs):  # noqa: E501
        """get_element_by_workspace_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_by_workspace_deprecated_with_http_info(did, wid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param bool with_thumbnails:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'with_thumbnails']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_element_by_workspace_deprecated" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_element_by_workspace_deprecated`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `get_element_by_workspace_deprecated`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []
        if 'with_thumbnails' in local_var_params:
            query_params.append(('withThumbnails', local_var_params['with_thumbnails']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/{did}/workspace/{wid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_element_metadata(self, did, wv, wvid, eid, **kwargs):  # noqa: E501
        """get_element_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_metadata(did, wv, wvid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_element_metadata_with_http_info(did, wv, wvid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_element_metadata_with_http_info(did, wv, wvid, eid, **kwargs)  # noqa: E501
            return data

    def get_element_metadata_with_http_info(self, did, wv, wvid, eid, **kwargs):  # noqa: E501
        """get_element_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_metadata_with_http_info(did, wv, wvid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_element_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_element_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `get_element_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `get_element_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_element_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/{wv}/{wvid}/e/{eid}/metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_element_metadata_deprecated(self, emid, **kwargs):  # noqa: E501
        """get_element_metadata_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_metadata_deprecated(emid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str emid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_element_metadata_deprecated_with_http_info(emid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_element_metadata_deprecated_with_http_info(emid, **kwargs)  # noqa: E501
            return data

    def get_element_metadata_deprecated_with_http_info(self, emid, **kwargs):  # noqa: E501
        """get_element_metadata_deprecated  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_metadata_deprecated_with_http_info(emid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str emid: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['emid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_element_metadata_deprecated" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'emid' is set
        if ('emid' not in local_var_params or
                local_var_params['emid'] is None):
            raise ValueError("Missing the required parameter `emid` when calling `get_element_metadata_deprecated`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'emid' in local_var_params:
            path_params['emid'] = local_var_params['emid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/{emid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_element_translator_formats1(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_element_translator_formats1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_translator_formats1(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param bool check_content:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_element_translator_formats1_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_element_translator_formats1_with_http_info(did, wid, eid, **kwargs)  # noqa: E501
            return data

    def get_element_translator_formats1_with_http_info(self, did, wid, eid, **kwargs):  # noqa: E501
        """get_element_translator_formats1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_element_translator_formats1_with_http_info(did, wid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param bool check_content:
        :param str configuration:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'check_content', 'configuration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_element_translator_formats1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_element_translator_formats1`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `get_element_translator_formats1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_element_translator_formats1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'check_content' in local_var_params:
            query_params.append(('checkContent', local_var_params['check_content']))  # noqa: E501
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/translatorFormats/{did}/{wid}/{eid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_translator_formats3(self, **kwargs):  # noqa: E501
        """get_translator_formats3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats3(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_translator_formats3_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_translator_formats3_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_translator_formats3_with_http_info(self, **kwargs):  # noqa: E501
        """get_translator_formats3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_translator_formats3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_translator_formats3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/translatorFormats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_configuration2(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """update_configuration2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_configuration2(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_configuration2_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_configuration2_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def update_configuration2_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """update_configuration2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_configuration2_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_configuration2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_configuration2`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `update_configuration2`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `update_configuration2`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_configuration2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/{wvm}/{wvmid}/e/{eid}/configuration', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_element_metadata(self, did, wv, wvid, eid, btpdm_metadata_params, **kwargs):  # noqa: E501
        """update_element_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_element_metadata(did, wv, wvid, eid, btpdm_metadata_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTPDMMetadataParams btpdm_metadata_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_element_metadata_with_http_info(did, wv, wvid, eid, btpdm_metadata_params, **kwargs)  # noqa: E501
        else:
            (data) = self.update_element_metadata_with_http_info(did, wv, wvid, eid, btpdm_metadata_params, **kwargs)  # noqa: E501
            return data

    def update_element_metadata_with_http_info(self, did, wv, wvid, eid, btpdm_metadata_params, **kwargs):  # noqa: E501
        """update_element_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_element_metadata_with_http_info(did, wv, wvid, eid, btpdm_metadata_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param BTPDMMetadataParams btpdm_metadata_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'btpdm_metadata_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_element_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_element_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `update_element_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `update_element_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_element_metadata`")  # noqa: E501
        # verify the required parameter 'btpdm_metadata_params' is set
        if ('btpdm_metadata_params' not in local_var_params or
                local_var_params['btpdm_metadata_params'] is None):
            raise ValueError("Missing the required parameter `btpdm_metadata_params` when calling `update_element_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'btpdm_metadata_params' in local_var_params:
            body_params = local_var_params['btpdm_metadata_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/{wv}/{wvid}/e/{eid}/metadata', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_references1(self, did, wid, eid, bt_update_reference_params, **kwargs):  # noqa: E501
        """update_references1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_references1(did, wid, eid, bt_update_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param BTUpdateReferenceParams bt_update_reference_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_references1_with_http_info(did, wid, eid, bt_update_reference_params, **kwargs)  # noqa: E501
        else:
            (data) = self.update_references1_with_http_info(did, wid, eid, bt_update_reference_params, **kwargs)  # noqa: E501
            return data

    def update_references1_with_http_info(self, did, wid, eid, bt_update_reference_params, **kwargs):  # noqa: E501
        """update_references1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_references1_with_http_info(did, wid, eid, bt_update_reference_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wid: (required)
        :param str eid: (required)
        :param BTUpdateReferenceParams bt_update_reference_params: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'eid', 'bt_update_reference_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_references1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_references1`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ValueError("Missing the required parameter `wid` when calling `update_references1`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_references1`")  # noqa: E501
        # verify the required parameter 'bt_update_reference_params' is set
        if ('bt_update_reference_params' not in local_var_params or
                local_var_params['bt_update_reference_params'] is None):
            raise ValueError("Missing the required parameter `bt_update_reference_params` when calling `update_references1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_update_reference_params' in local_var_params:
            body_params = local_var_params['bt_update_reference_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/d/{did}/w/{wid}/e/{eid}/updatereferences', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_file2(self, did, **kwargs):  # noqa: E501
        """upload_file2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file2(did, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str element_id:
        :param str workspace_id:
        :param ContentDisposition content_disposition:
        :param object entity:
        :param BodyPartHeaders headers:
        :param BodyPartMediaType media_type:
        :param MessageBodyWorkers message_body_workers:
        :param MultiPart parent:
        :param object providers:
        :param list[BodyPart] body_parts:
        :param BodyPartHeaders parameterized_headers:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_file2_with_http_info(did, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_file2_with_http_info(did, **kwargs)  # noqa: E501
            return data

    def upload_file2_with_http_info(self, did, **kwargs):  # noqa: E501
        """upload_file2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file2_with_http_info(did, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str element_id:
        :param str workspace_id:
        :param ContentDisposition content_disposition:
        :param object entity:
        :param BodyPartHeaders headers:
        :param BodyPartMediaType media_type:
        :param MessageBodyWorkers message_body_workers:
        :param MultiPart parent:
        :param object providers:
        :param list[BodyPart] body_parts:
        :param BodyPartHeaders parameterized_headers:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'element_id', 'workspace_id', 'content_disposition', 'entity', 'headers', 'media_type', 'message_body_workers', 'parent', 'providers', 'body_parts', 'parameterized_headers']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `upload_file2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501

        query_params = []
        if 'element_id' in local_var_params:
            query_params.append(('elementId', local_var_params['element_id']))  # noqa: E501
        if 'workspace_id' in local_var_params:
            query_params.append(('workspaceId', local_var_params['workspace_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'content_disposition' in local_var_params:
            form_params.append(('contentDisposition', local_var_params['content_disposition']))  # noqa: E501
        if 'entity' in local_var_params:
            form_params.append(('entity', local_var_params['entity']))  # noqa: E501
        if 'headers' in local_var_params:
            form_params.append(('headers', local_var_params['headers']))  # noqa: E501
        if 'media_type' in local_var_params:
            form_params.append(('mediaType', local_var_params['media_type']))  # noqa: E501
        if 'message_body_workers' in local_var_params:
            form_params.append(('messageBodyWorkers', local_var_params['message_body_workers']))  # noqa: E501
        if 'parent' in local_var_params:
            form_params.append(('parent', local_var_params['parent']))  # noqa: E501
        if 'providers' in local_var_params:
            form_params.append(('providers', local_var_params['providers']))  # noqa: E501
        if 'body_parts' in local_var_params:
            form_params.append(('bodyParts', local_var_params['body_parts']))  # noqa: E501
            collection_formats['bodyParts'] = 'csv'  # noqa: E501
        if 'parameterized_headers' in local_var_params:
            form_params.append(('parameterizedHeaders', local_var_params['parameterized_headers']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/elements/upload/{did}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.93
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWorkflowInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'actions': 'list[BTActionInfo]',
        'state': 'BTWorkflowStateInfo',
        'rejected_by': 'list[str]',
        'is_setup': 'bool',
        'approved_by': 'list[str]',
        'is_frozen': 'bool',
        'is_initial_state': 'bool',
        'approver_ids': 'list[str]',
        'notifier_ids': 'list[str]',
        'workflow_id': 'str',
        'metadata_state': 'str',
        'is_discarded': 'bool'
    }

    attribute_map = {
        'actions': 'actions',
        'state': 'state',
        'rejected_by': 'rejectedBy',
        'is_setup': 'isSetup',
        'approved_by': 'approvedBy',
        'is_frozen': 'isFrozen',
        'is_initial_state': 'isInitialState',
        'approver_ids': 'approverIds',
        'notifier_ids': 'notifierIds',
        'workflow_id': 'workflowId',
        'metadata_state': 'metadataState',
        'is_discarded': 'isDiscarded'
    }

    def __init__(self, actions=None, state=None, rejected_by=None, is_setup=None, approved_by=None, is_frozen=None, is_initial_state=None, approver_ids=None, notifier_ids=None, workflow_id=None, metadata_state=None, is_discarded=None):  # noqa: E501
        """BTWorkflowInfo - a model defined in OpenAPI"""  # noqa: E501

        self._actions = None
        self._state = None
        self._rejected_by = None
        self._is_setup = None
        self._approved_by = None
        self._is_frozen = None
        self._is_initial_state = None
        self._approver_ids = None
        self._notifier_ids = None
        self._workflow_id = None
        self._metadata_state = None
        self._is_discarded = None
        self.discriminator = None

        if actions is not None:
            self.actions = actions
        if state is not None:
            self.state = state
        if rejected_by is not None:
            self.rejected_by = rejected_by
        if is_setup is not None:
            self.is_setup = is_setup
        if approved_by is not None:
            self.approved_by = approved_by
        if is_frozen is not None:
            self.is_frozen = is_frozen
        if is_initial_state is not None:
            self.is_initial_state = is_initial_state
        if approver_ids is not None:
            self.approver_ids = approver_ids
        if notifier_ids is not None:
            self.notifier_ids = notifier_ids
        if workflow_id is not None:
            self.workflow_id = workflow_id
        if metadata_state is not None:
            self.metadata_state = metadata_state
        if is_discarded is not None:
            self.is_discarded = is_discarded

    @property
    def actions(self):
        """Gets the actions of this BTWorkflowInfo.  # noqa: E501


        :return: The actions of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[BTActionInfo]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this BTWorkflowInfo.


        :param actions: The actions of this BTWorkflowInfo.  # noqa: E501
        :type: list[BTActionInfo]
        """

        self._actions = actions

    @property
    def state(self):
        """Gets the state of this BTWorkflowInfo.  # noqa: E501


        :return: The state of this BTWorkflowInfo.  # noqa: E501
        :rtype: BTWorkflowStateInfo
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTWorkflowInfo.


        :param state: The state of this BTWorkflowInfo.  # noqa: E501
        :type: BTWorkflowStateInfo
        """

        self._state = state

    @property
    def rejected_by(self):
        """Gets the rejected_by of this BTWorkflowInfo.  # noqa: E501


        :return: The rejected_by of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._rejected_by

    @rejected_by.setter
    def rejected_by(self, rejected_by):
        """Sets the rejected_by of this BTWorkflowInfo.


        :param rejected_by: The rejected_by of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._rejected_by = rejected_by

    @property
    def is_setup(self):
        """Gets the is_setup of this BTWorkflowInfo.  # noqa: E501


        :return: The is_setup of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_setup

    @is_setup.setter
    def is_setup(self, is_setup):
        """Sets the is_setup of this BTWorkflowInfo.


        :param is_setup: The is_setup of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_setup = is_setup

    @property
    def approved_by(self):
        """Gets the approved_by of this BTWorkflowInfo.  # noqa: E501


        :return: The approved_by of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._approved_by

    @approved_by.setter
    def approved_by(self, approved_by):
        """Sets the approved_by of this BTWorkflowInfo.


        :param approved_by: The approved_by of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._approved_by = approved_by

    @property
    def is_frozen(self):
        """Gets the is_frozen of this BTWorkflowInfo.  # noqa: E501


        :return: The is_frozen of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_frozen

    @is_frozen.setter
    def is_frozen(self, is_frozen):
        """Sets the is_frozen of this BTWorkflowInfo.


        :param is_frozen: The is_frozen of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_frozen = is_frozen

    @property
    def is_initial_state(self):
        """Gets the is_initial_state of this BTWorkflowInfo.  # noqa: E501


        :return: The is_initial_state of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_initial_state

    @is_initial_state.setter
    def is_initial_state(self, is_initial_state):
        """Sets the is_initial_state of this BTWorkflowInfo.


        :param is_initial_state: The is_initial_state of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_initial_state = is_initial_state

    @property
    def approver_ids(self):
        """Gets the approver_ids of this BTWorkflowInfo.  # noqa: E501


        :return: The approver_ids of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._approver_ids

    @approver_ids.setter
    def approver_ids(self, approver_ids):
        """Sets the approver_ids of this BTWorkflowInfo.


        :param approver_ids: The approver_ids of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._approver_ids = approver_ids

    @property
    def notifier_ids(self):
        """Gets the notifier_ids of this BTWorkflowInfo.  # noqa: E501


        :return: The notifier_ids of this BTWorkflowInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._notifier_ids

    @notifier_ids.setter
    def notifier_ids(self, notifier_ids):
        """Sets the notifier_ids of this BTWorkflowInfo.


        :param notifier_ids: The notifier_ids of this BTWorkflowInfo.  # noqa: E501
        :type: list[str]
        """

        self._notifier_ids = notifier_ids

    @property
    def workflow_id(self):
        """Gets the workflow_id of this BTWorkflowInfo.  # noqa: E501


        :return: The workflow_id of this BTWorkflowInfo.  # noqa: E501
        :rtype: str
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this BTWorkflowInfo.


        :param workflow_id: The workflow_id of this BTWorkflowInfo.  # noqa: E501
        :type: str
        """

        self._workflow_id = workflow_id

    @property
    def metadata_state(self):
        """Gets the metadata_state of this BTWorkflowInfo.  # noqa: E501


        :return: The metadata_state of this BTWorkflowInfo.  # noqa: E501
        :rtype: str
        """
        return self._metadata_state

    @metadata_state.setter
    def metadata_state(self, metadata_state):
        """Sets the metadata_state of this BTWorkflowInfo.


        :param metadata_state: The metadata_state of this BTWorkflowInfo.  # noqa: E501
        :type: str
        """

        self._metadata_state = metadata_state

    @property
    def is_discarded(self):
        """Gets the is_discarded of this BTWorkflowInfo.  # noqa: E501


        :return: The is_discarded of this BTWorkflowInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_discarded

    @is_discarded.setter
    def is_discarded(self, is_discarded):
        """Sets the is_discarded of this BTWorkflowInfo.


        :param is_discarded: The is_discarded of this BTWorkflowInfo.  # noqa: E501
        :type: bool
        """

        self._is_discarded = is_discarded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWorkflowInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTToolTreeParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'context': 'int',
        'priority': 'int',
        'id': 'str',
        'active': 'bool',
        'namespace': 'str',
        'owner_id': 'str',
        'use_history': 'bool',
        'mini': 'bool',
        'collection_name': 'str',
        'icon': 'str',
        'owner_type': 'int',
        'capability': 'str',
        'node_type': 'int',
        'tool_name': 'str',
        'tooltip_key': 'str',
        'expanded_tooltip_key': 'str',
        'command': 'str',
        'command_details': 'str',
        'feature_spec_name': 'str',
        'fs_version': 'int',
        'use_dynamic_snippet': 'bool',
        'icon_initials': 'str',
        'context_menu': 'str',
        'is_newer_version_available': 'bool'
    }

    attribute_map = {
        'context': 'context',
        'priority': 'priority',
        'id': 'id',
        'active': 'active',
        'namespace': 'namespace',
        'owner_id': 'ownerId',
        'use_history': 'useHistory',
        'mini': 'mini',
        'collection_name': 'collectionName',
        'icon': 'icon',
        'owner_type': 'ownerType',
        'capability': 'capability',
        'node_type': 'nodeType',
        'tool_name': 'toolName',
        'tooltip_key': 'tooltipKey',
        'expanded_tooltip_key': 'expandedTooltipKey',
        'command': 'command',
        'command_details': 'commandDetails',
        'feature_spec_name': 'featureSpecName',
        'fs_version': 'fsVersion',
        'use_dynamic_snippet': 'useDynamicSnippet',
        'icon_initials': 'iconInitials',
        'context_menu': 'contextMenu',
        'is_newer_version_available': 'isNewerVersionAvailable'
    }

    def __init__(self, context=None, priority=None, id=None, active=None, namespace=None, owner_id=None, use_history=None, mini=None, collection_name=None, icon=None, owner_type=None, capability=None, node_type=None, tool_name=None, tooltip_key=None, expanded_tooltip_key=None, command=None, command_details=None, feature_spec_name=None, fs_version=None, use_dynamic_snippet=None, icon_initials=None, context_menu=None, is_newer_version_available=None):  # noqa: E501
        """BTToolTreeParams - a model defined in OpenAPI"""  # noqa: E501

        self._context = None
        self._priority = None
        self._id = None
        self._active = None
        self._namespace = None
        self._owner_id = None
        self._use_history = None
        self._mini = None
        self._collection_name = None
        self._icon = None
        self._owner_type = None
        self._capability = None
        self._node_type = None
        self._tool_name = None
        self._tooltip_key = None
        self._expanded_tooltip_key = None
        self._command = None
        self._command_details = None
        self._feature_spec_name = None
        self._fs_version = None
        self._use_dynamic_snippet = None
        self._icon_initials = None
        self._context_menu = None
        self._is_newer_version_available = None
        self.discriminator = None

        if context is not None:
            self.context = context
        if priority is not None:
            self.priority = priority
        if id is not None:
            self.id = id
        if active is not None:
            self.active = active
        if namespace is not None:
            self.namespace = namespace
        if owner_id is not None:
            self.owner_id = owner_id
        if use_history is not None:
            self.use_history = use_history
        if mini is not None:
            self.mini = mini
        if collection_name is not None:
            self.collection_name = collection_name
        if icon is not None:
            self.icon = icon
        if owner_type is not None:
            self.owner_type = owner_type
        if capability is not None:
            self.capability = capability
        if node_type is not None:
            self.node_type = node_type
        if tool_name is not None:
            self.tool_name = tool_name
        if tooltip_key is not None:
            self.tooltip_key = tooltip_key
        if expanded_tooltip_key is not None:
            self.expanded_tooltip_key = expanded_tooltip_key
        if command is not None:
            self.command = command
        if command_details is not None:
            self.command_details = command_details
        if feature_spec_name is not None:
            self.feature_spec_name = feature_spec_name
        if fs_version is not None:
            self.fs_version = fs_version
        if use_dynamic_snippet is not None:
            self.use_dynamic_snippet = use_dynamic_snippet
        if icon_initials is not None:
            self.icon_initials = icon_initials
        if context_menu is not None:
            self.context_menu = context_menu
        if is_newer_version_available is not None:
            self.is_newer_version_available = is_newer_version_available

    @property
    def context(self):
        """Gets the context of this BTToolTreeParams.  # noqa: E501


        :return: The context of this BTToolTreeParams.  # noqa: E501
        :rtype: int
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this BTToolTreeParams.


        :param context: The context of this BTToolTreeParams.  # noqa: E501
        :type: int
        """

        self._context = context

    @property
    def priority(self):
        """Gets the priority of this BTToolTreeParams.  # noqa: E501


        :return: The priority of this BTToolTreeParams.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this BTToolTreeParams.


        :param priority: The priority of this BTToolTreeParams.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def id(self):
        """Gets the id of this BTToolTreeParams.  # noqa: E501


        :return: The id of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTToolTreeParams.


        :param id: The id of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def active(self):
        """Gets the active of this BTToolTreeParams.  # noqa: E501


        :return: The active of this BTToolTreeParams.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this BTToolTreeParams.


        :param active: The active of this BTToolTreeParams.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def namespace(self):
        """Gets the namespace of this BTToolTreeParams.  # noqa: E501


        :return: The namespace of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTToolTreeParams.


        :param namespace: The namespace of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def owner_id(self):
        """Gets the owner_id of this BTToolTreeParams.  # noqa: E501


        :return: The owner_id of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTToolTreeParams.


        :param owner_id: The owner_id of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def use_history(self):
        """Gets the use_history of this BTToolTreeParams.  # noqa: E501


        :return: The use_history of this BTToolTreeParams.  # noqa: E501
        :rtype: bool
        """
        return self._use_history

    @use_history.setter
    def use_history(self, use_history):
        """Sets the use_history of this BTToolTreeParams.


        :param use_history: The use_history of this BTToolTreeParams.  # noqa: E501
        :type: bool
        """

        self._use_history = use_history

    @property
    def mini(self):
        """Gets the mini of this BTToolTreeParams.  # noqa: E501


        :return: The mini of this BTToolTreeParams.  # noqa: E501
        :rtype: bool
        """
        return self._mini

    @mini.setter
    def mini(self, mini):
        """Sets the mini of this BTToolTreeParams.


        :param mini: The mini of this BTToolTreeParams.  # noqa: E501
        :type: bool
        """

        self._mini = mini

    @property
    def collection_name(self):
        """Gets the collection_name of this BTToolTreeParams.  # noqa: E501


        :return: The collection_name of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._collection_name

    @collection_name.setter
    def collection_name(self, collection_name):
        """Sets the collection_name of this BTToolTreeParams.


        :param collection_name: The collection_name of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._collection_name = collection_name

    @property
    def icon(self):
        """Gets the icon of this BTToolTreeParams.  # noqa: E501


        :return: The icon of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this BTToolTreeParams.


        :param icon: The icon of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def owner_type(self):
        """Gets the owner_type of this BTToolTreeParams.  # noqa: E501


        :return: The owner_type of this BTToolTreeParams.  # noqa: E501
        :rtype: int
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """Sets the owner_type of this BTToolTreeParams.


        :param owner_type: The owner_type of this BTToolTreeParams.  # noqa: E501
        :type: int
        """

        self._owner_type = owner_type

    @property
    def capability(self):
        """Gets the capability of this BTToolTreeParams.  # noqa: E501


        :return: The capability of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._capability

    @capability.setter
    def capability(self, capability):
        """Sets the capability of this BTToolTreeParams.


        :param capability: The capability of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._capability = capability

    @property
    def node_type(self):
        """Gets the node_type of this BTToolTreeParams.  # noqa: E501


        :return: The node_type of this BTToolTreeParams.  # noqa: E501
        :rtype: int
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this BTToolTreeParams.


        :param node_type: The node_type of this BTToolTreeParams.  # noqa: E501
        :type: int
        """

        self._node_type = node_type

    @property
    def tool_name(self):
        """Gets the tool_name of this BTToolTreeParams.  # noqa: E501


        :return: The tool_name of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._tool_name

    @tool_name.setter
    def tool_name(self, tool_name):
        """Sets the tool_name of this BTToolTreeParams.


        :param tool_name: The tool_name of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._tool_name = tool_name

    @property
    def tooltip_key(self):
        """Gets the tooltip_key of this BTToolTreeParams.  # noqa: E501


        :return: The tooltip_key of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._tooltip_key

    @tooltip_key.setter
    def tooltip_key(self, tooltip_key):
        """Sets the tooltip_key of this BTToolTreeParams.


        :param tooltip_key: The tooltip_key of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._tooltip_key = tooltip_key

    @property
    def expanded_tooltip_key(self):
        """Gets the expanded_tooltip_key of this BTToolTreeParams.  # noqa: E501


        :return: The expanded_tooltip_key of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._expanded_tooltip_key

    @expanded_tooltip_key.setter
    def expanded_tooltip_key(self, expanded_tooltip_key):
        """Sets the expanded_tooltip_key of this BTToolTreeParams.


        :param expanded_tooltip_key: The expanded_tooltip_key of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._expanded_tooltip_key = expanded_tooltip_key

    @property
    def command(self):
        """Gets the command of this BTToolTreeParams.  # noqa: E501


        :return: The command of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this BTToolTreeParams.


        :param command: The command of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._command = command

    @property
    def command_details(self):
        """Gets the command_details of this BTToolTreeParams.  # noqa: E501


        :return: The command_details of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._command_details

    @command_details.setter
    def command_details(self, command_details):
        """Sets the command_details of this BTToolTreeParams.


        :param command_details: The command_details of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._command_details = command_details

    @property
    def feature_spec_name(self):
        """Gets the feature_spec_name of this BTToolTreeParams.  # noqa: E501


        :return: The feature_spec_name of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._feature_spec_name

    @feature_spec_name.setter
    def feature_spec_name(self, feature_spec_name):
        """Sets the feature_spec_name of this BTToolTreeParams.


        :param feature_spec_name: The feature_spec_name of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._feature_spec_name = feature_spec_name

    @property
    def fs_version(self):
        """Gets the fs_version of this BTToolTreeParams.  # noqa: E501


        :return: The fs_version of this BTToolTreeParams.  # noqa: E501
        :rtype: int
        """
        return self._fs_version

    @fs_version.setter
    def fs_version(self, fs_version):
        """Sets the fs_version of this BTToolTreeParams.


        :param fs_version: The fs_version of this BTToolTreeParams.  # noqa: E501
        :type: int
        """

        self._fs_version = fs_version

    @property
    def use_dynamic_snippet(self):
        """Gets the use_dynamic_snippet of this BTToolTreeParams.  # noqa: E501


        :return: The use_dynamic_snippet of this BTToolTreeParams.  # noqa: E501
        :rtype: bool
        """
        return self._use_dynamic_snippet

    @use_dynamic_snippet.setter
    def use_dynamic_snippet(self, use_dynamic_snippet):
        """Sets the use_dynamic_snippet of this BTToolTreeParams.


        :param use_dynamic_snippet: The use_dynamic_snippet of this BTToolTreeParams.  # noqa: E501
        :type: bool
        """

        self._use_dynamic_snippet = use_dynamic_snippet

    @property
    def icon_initials(self):
        """Gets the icon_initials of this BTToolTreeParams.  # noqa: E501


        :return: The icon_initials of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._icon_initials

    @icon_initials.setter
    def icon_initials(self, icon_initials):
        """Sets the icon_initials of this BTToolTreeParams.


        :param icon_initials: The icon_initials of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._icon_initials = icon_initials

    @property
    def context_menu(self):
        """Gets the context_menu of this BTToolTreeParams.  # noqa: E501


        :return: The context_menu of this BTToolTreeParams.  # noqa: E501
        :rtype: str
        """
        return self._context_menu

    @context_menu.setter
    def context_menu(self, context_menu):
        """Sets the context_menu of this BTToolTreeParams.


        :param context_menu: The context_menu of this BTToolTreeParams.  # noqa: E501
        :type: str
        """

        self._context_menu = context_menu

    @property
    def is_newer_version_available(self):
        """Gets the is_newer_version_available of this BTToolTreeParams.  # noqa: E501


        :return: The is_newer_version_available of this BTToolTreeParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_newer_version_available

    @is_newer_version_available.setter
    def is_newer_version_available(self, is_newer_version_available):
        """Sets the is_newer_version_available of this BTToolTreeParams.


        :param is_newer_version_available: The is_newer_version_available of this BTToolTreeParams.  # noqa: E501
        :type: bool
        """

        self._is_newer_version_available = is_newer_version_available

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTToolTreeParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
